From 65a26804fb76825f7a98022347aca6a3d17aadb8 Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter_e@gmx.net>
Date: Mon, 19 Jun 2017 17:52:56 -0400
Subject: [PATCH] Remove endterms and title ids

Older documentation toolchains could not automatically generate text for
xrefs into refentries, so we had to use the endterm attribute to tell it
which text to create.  This is no longer necessary and can be removed.
In most cases, we can just rely on the automatically generated text.  In
the cases where that doesn't work, use the link element instead to
create the desired text locally instead of relying on text at a remote
location.
---
 doc/src/sgml/README.links                      |  4 --
 doc/src/sgml/config.sgml                       |  3 +-
 doc/src/sgml/indices.sgml                      |  3 +-
 doc/src/sgml/maintenance.sgml                  |  3 +-
 doc/src/sgml/queries.sgml                      |  7 ++-
 doc/src/sgml/ref/alter_collation.sgml          |  5 +-
 doc/src/sgml/ref/alter_table.sgml              |  3 +-
 doc/src/sgml/ref/commit_prepared.sgml          |  2 +-
 doc/src/sgml/ref/create_aggregate.sgml         |  6 +--
 doc/src/sgml/ref/create_foreign_table.sgml     |  2 +-
 doc/src/sgml/ref/create_index.sgml             |  9 ++--
 doc/src/sgml/ref/create_materialized_view.sgml |  3 +-
 doc/src/sgml/ref/create_table.sgml             | 10 ++--
 doc/src/sgml/ref/create_table_as.sgml          |  3 +-
 doc/src/sgml/ref/create_view.sgml              |  2 +-
 doc/src/sgml/ref/declare.sgml                  |  5 +-
 doc/src/sgml/ref/delete.sgml                   |  4 +-
 doc/src/sgml/ref/do.sgml                       |  2 +-
 doc/src/sgml/ref/execute.sgml                  |  4 +-
 doc/src/sgml/ref/insert.sgml                   |  7 ++-
 doc/src/sgml/ref/lock.sgml                     |  3 +-
 doc/src/sgml/ref/pg_dump.sgml                  | 12 ++---
 doc/src/sgml/ref/postgres-ref.sgml             |  5 +-
 doc/src/sgml/ref/prepare.sgml                  |  2 +-
 doc/src/sgml/ref/prepare_transaction.sgml      |  2 +-
 doc/src/sgml/ref/psql-ref.sgml                 | 49 ++++++++-----------
 doc/src/sgml/ref/rollback_prepared.sgml        |  2 +-
 doc/src/sgml/ref/select.sgml                   | 67 ++++++++++++--------------
 doc/src/sgml/ref/update.sgml                   |  4 +-
 doc/src/sgml/ref/values.sgml                   |  8 +--
 30 files changed, 104 insertions(+), 137 deletions(-)

diff --git a/doc/src/sgml/README.links b/doc/src/sgml/README.links
index f64b857316..4050de140c 100644
--- a/doc/src/sgml/README.links
+++ b/doc/src/sgml/README.links
@@ -19,10 +19,6 @@ Intra-document Linking
 linkend=
 	controls the target of the link/xref, required
 
-endterm=
-	for <xref>, allows the text of the link/xref to be taken from a
-	different link target title
-
 
 External Linking
 ----------------
diff --git a/doc/src/sgml/config.sgml b/doc/src/sgml/config.sgml
index 533faf060d..750db427dc 100644
--- a/doc/src/sgml/config.sgml
+++ b/doc/src/sgml/config.sgml
@@ -5894,8 +5894,7 @@ <title>Automatic Vacuuming</title>
       These settings control the behavior of the <firstterm>autovacuum</firstterm>
       feature.  Refer to <xref linkend="autovacuum"/> for more information.
       Note that many of these settings can be overridden on a per-table
-      basis; see <xref linkend="sql-createtable-storage-parameters"
-      endterm="sql-createtable-storage-parameters-title"/>.
+      basis; see <xref linkend="sql-createtable-storage-parameters"/>.
      </para>
 
     <variablelist>
diff --git a/doc/src/sgml/indices.sgml b/doc/src/sgml/indices.sgml
index 0818196e76..f60d16e812 100644
--- a/doc/src/sgml/indices.sgml
+++ b/doc/src/sgml/indices.sgml
@@ -98,8 +98,7 @@ <title>Introduction</title>
    In production environments this is often unacceptable.
    It is possible to allow writes to occur in parallel with index
    creation, but there are several caveats to be aware of &mdash;
-   for more information see <xref linkend="sql-createindex-concurrently"
-   endterm="sql-createindex-concurrently-title"/>.
+   for more information see <xref linkend="sql-createindex-concurrently"/>.
   </para>
 
   <para>
diff --git a/doc/src/sgml/maintenance.sgml b/doc/src/sgml/maintenance.sgml
index 4a68ec3b40..e4341e252c 100644
--- a/doc/src/sgml/maintenance.sgml
+++ b/doc/src/sgml/maintenance.sgml
@@ -807,8 +807,7 @@ <title>The Autovacuum Daemon</title>
     The default thresholds and scale factors are taken from
     <filename>postgresql.conf</filename>, but it is possible to override them
     (and many other autovacuum control parameters) on a per-table basis; see
-    <xref linkend="sql-createtable-storage-parameters"
-    endterm="sql-createtable-storage-parameters-title"/> for more information.
+    <xref linkend="sql-createtable-storage-parameters"/> for more information.
     If a setting has been changed via a table's storage parameters, that value
     is used when processing that table; otherwise the global settings are
     used. See <xref linkend="runtime-config-autovacuum"/> for more details on
diff --git a/doc/src/sgml/queries.sgml b/doc/src/sgml/queries.sgml
index 19a7d2e18b..e98a30d836 100644
--- a/doc/src/sgml/queries.sgml
+++ b/doc/src/sgml/queries.sgml
@@ -110,7 +110,7 @@ <title>Table Expressions</title>
    <title>The <literal>FROM</literal> Clause</title>
 
    <para>
-    The <xref linkend="sql-from" endterm="sql-from-title"/> derives a
+    The <literal>FROM</literal> clause derives a
     table from one or more other tables given in a comma-separated
     table reference list.
 <synopsis>
@@ -907,8 +907,7 @@ <title>The <literal>WHERE</literal> Clause</title>
    </indexterm>
 
    <para>
-    The syntax of the <xref linkend="sql-where"
-    endterm="sql-where-title"/> is
+    The syntax of the <literal>WHERE</literal> clause is
 <synopsis>
 WHERE <replaceable>search_condition</replaceable>
 </synopsis>
@@ -1014,7 +1013,7 @@ <title>The <literal>GROUP BY</literal> and <literal>HAVING</literal> Clauses</ti
 </synopsis>
 
    <para>
-    The <xref linkend="sql-groupby" endterm="sql-groupby-title"/> is
+    The <literal>GROUP BY</literal> clause is
     used to group together those rows in a table that have the same
     values in all the columns listed. The order in which the columns
     are listed does not matter.  The effect is to combine each set
diff --git a/doc/src/sgml/ref/alter_collation.sgml b/doc/src/sgml/ref/alter_collation.sgml
index b51b3a2564..683b3c542a 100644
--- a/doc/src/sgml/ref/alter_collation.sgml
+++ b/doc/src/sgml/ref/alter_collation.sgml
@@ -93,8 +93,7 @@ <title>Parameters</title>
     <listitem>
      <para>
       Update the collation's version.
-      See <xref linkend="sql-altercollation-notes"
-      endterm="sql-altercollation-notes-title"/> below.
+      See <xref linkend="sql-altercollation-notes"/> below.
      </para>
     </listitem>
    </varlistentry>
@@ -102,7 +101,7 @@ <title>Parameters</title>
  </refsect1>
 
  <refsect1 id="sql-altercollation-notes">
-  <title id="sql-altercollation-notes-title">Notes</title>
+  <title>Notes</title>
 
   <para>
    When using collations provided by the ICU library, the ICU-specific version
diff --git a/doc/src/sgml/ref/alter_table.sgml b/doc/src/sgml/ref/alter_table.sgml
index 7bcf242846..cf255e6efc 100644
--- a/doc/src/sgml/ref/alter_table.sgml
+++ b/doc/src/sgml/ref/alter_table.sgml
@@ -614,8 +614,7 @@ <title>Description</title>
     <listitem>
      <para>
       This form changes one or more storage parameters for the table.  See
-      <xref linkend="sql-createtable-storage-parameters"
-      endterm="sql-createtable-storage-parameters-title"/>
+      <xref linkend="sql-createtable-storage-parameters"/>
       for details on the available parameters.  Note that the table contents
       will not be modified immediately by this command; depending on the
       parameter you might need to rewrite the table to get the desired effects.
diff --git a/doc/src/sgml/ref/commit_prepared.sgml b/doc/src/sgml/ref/commit_prepared.sgml
index d938b65bbe..7299f735c9 100644
--- a/doc/src/sgml/ref/commit_prepared.sgml
+++ b/doc/src/sgml/ref/commit_prepared.sgml
@@ -72,7 +72,7 @@ <title>Notes</title>
  </refsect1>
 
  <refsect1 id="sql-commit-prepared-examples">
-  <title id="sql-commit-prepared-examples-title">Examples</title>
+  <title>Examples</title>
   <para>
    Commit the transaction identified by the transaction
    identifier <literal>foobar</literal>:
diff --git a/doc/src/sgml/ref/create_aggregate.sgml b/doc/src/sgml/ref/create_aggregate.sgml
index a4aaae876e..244b42c321 100644
--- a/doc/src/sgml/ref/create_aggregate.sgml
+++ b/doc/src/sgml/ref/create_aggregate.sgml
@@ -425,8 +425,8 @@ <title>Parameters</title>
       This option specifies whether the final function is a pure function
       that does not modify its arguments.  <literal>READ_ONLY</literal> indicates
       it does not; the other two values indicate that it may change the
-      transition state value.  See <xref linkend="sql-createaggregate-notes"
-      endterm="sql-createaggregate-notes-title"/> below for more detail.  The
+      transition state value.  See <xref linkend="sql-createaggregate-notes"/>
+      below for more detail.  The
       default is <literal>READ_ONLY</literal>, except for ordered-set aggregates,
       for which the default is <literal>READ_WRITE</literal>.
      </para>
@@ -656,7 +656,7 @@ <title>Parameters</title>
  </refsect1>
 
  <refsect1 id="sql-createaggregate-notes">
-  <title id="sql-createaggregate-notes-title">Notes</title>
+  <title>Notes</title>
 
    <para>
     In parameters that specify support function names, you can write
diff --git a/doc/src/sgml/ref/create_foreign_table.sgml b/doc/src/sgml/ref/create_foreign_table.sgml
index 37a45b26db..c7b6edfc1f 100644
--- a/doc/src/sgml/ref/create_foreign_table.sgml
+++ b/doc/src/sgml/ref/create_foreign_table.sgml
@@ -343,7 +343,7 @@ <title>Examples</title>
  </refsect1>
 
  <refsect1 id="sql-createforeigntable-compatibility">
-  <title id="sql-createforeigntable-compatibility-title">Compatibility</title>
+  <title>Compatibility</title>
 
   <para>
    The <command>CREATE FOREIGN TABLE</command> command largely conforms to the
diff --git a/doc/src/sgml/ref/create_index.sgml b/doc/src/sgml/ref/create_index.sgml
index 025537575b..4943594ed6 100644
--- a/doc/src/sgml/ref/create_index.sgml
+++ b/doc/src/sgml/ref/create_index.sgml
@@ -120,8 +120,7 @@ <title>Parameters</title>
         updates, or deletes on the table; whereas a standard index build
         locks out writes (but not reads) on the table until it's done.
         There are several caveats to be aware of when using this option
-        &mdash; see <xref linkend="sql-createindex-concurrently"
-        endterm="sql-createindex-concurrently-title"/>.
+        &mdash; see <xref linkend="sql-createindex-concurrently"/>.
        </para>
       </listitem>
      </varlistentry>
@@ -259,7 +258,7 @@ <title>Parameters</title>
       <listitem>
        <para>
         The name of an index-method-specific storage parameter.  See
-        <xref linkend="sql-createindex-storage-parameters" endterm="sql-createindex-storage-parameters-title"/>
+        <xref linkend="sql-createindex-storage-parameters"/>
         for details.
        </para>
       </listitem>
@@ -289,7 +288,7 @@ <title>Parameters</title>
     </variablelist>
 
   <refsect2 id="sql-createindex-storage-parameters">
-   <title id="sql-createindex-storage-parameters-title">Index Storage Parameters</title>
+   <title>Index Storage Parameters</title>
 
    <para>
     The optional <literal>WITH</literal> clause specifies <firstterm>storage
@@ -410,7 +409,7 @@ <title id="sql-createindex-storage-parameters-title">Index Storage Parameters</t
   </refsect2>
 
   <refsect2 id="sql-createindex-concurrently">
-   <title id="sql-createindex-concurrently-title">Building Indexes Concurrently</title>
+   <title>Building Indexes Concurrently</title>
 
    <indexterm zone="sql-createindex-concurrently">
    <primary>index</primary>
diff --git a/doc/src/sgml/ref/create_materialized_view.sgml b/doc/src/sgml/ref/create_materialized_view.sgml
index eed4273c4b..1f6a450dc5 100644
--- a/doc/src/sgml/ref/create_materialized_view.sgml
+++ b/doc/src/sgml/ref/create_materialized_view.sgml
@@ -91,8 +91,7 @@ <title>Parameters</title>
     <listitem>
      <para>
       This clause specifies optional storage parameters for the new
-      materialized view; see <xref linkend="sql-createtable-storage-parameters"
-      endterm="sql-createtable-storage-parameters-title"/> for more
+      materialized view; see <xref linkend="sql-createtable-storage-parameters"/> for more
       information.  All parameters supported for <literal>CREATE
       TABLE</literal> are also supported for <literal>CREATE MATERIALIZED
       VIEW</literal> with the exception of <literal>OIDS</literal>.
diff --git a/doc/src/sgml/ref/create_table.sgml b/doc/src/sgml/ref/create_table.sgml
index a0c9a6d257..ad230a1bc6 100644
--- a/doc/src/sgml/ref/create_table.sgml
+++ b/doc/src/sgml/ref/create_table.sgml
@@ -186,8 +186,7 @@ <title>Parameters</title>
       can be written before <literal>TEMPORARY</literal> or <literal>TEMP</literal>.
       This presently makes no difference in <productname>PostgreSQL</productname>
       and is deprecated; see
-      <xref linkend="sql-createtable-compatibility"
-      endterm="sql-createtable-compatibility-title"/>.
+      <xref linkend="sql-createtable-compatibility"/>.
      </para>
     </listitem>
    </varlistentry>
@@ -1035,8 +1034,7 @@ <title>Parameters</title>
     <listitem>
      <para>
       This clause specifies optional storage parameters for a table or index;
-      see <xref linkend="sql-createtable-storage-parameters"
-      endterm="sql-createtable-storage-parameters-title"/> for more
+      see <xref linkend="sql-createtable-storage-parameters"/> for more
       information.  The <literal>WITH</literal> clause for a
       table can also include <literal>OIDS=TRUE</literal> (or just <literal>OIDS</literal>)
       to specify that rows of the new table
@@ -1155,7 +1153,7 @@ <title>Parameters</title>
   </variablelist>
 
   <refsect2 id="sql-createtable-storage-parameters">
-   <title id="sql-createtable-storage-parameters-title">Storage Parameters</title>
+   <title>Storage Parameters</title>
 
  <indexterm zone="sql-createtable-storage-parameters">
   <primary>storage parameters</primary>
@@ -1788,7 +1786,7 @@ <title>Examples</title>
  </refsect1>
 
  <refsect1 id="sql-createtable-compatibility">
-  <title id="sql-createtable-compatibility-title">Compatibility</title>
+  <title>Compatibility</title>
 
   <para>
    The <command>CREATE TABLE</command> command conforms to the
diff --git a/doc/src/sgml/ref/create_table_as.sgml b/doc/src/sgml/ref/create_table_as.sgml
index 527138e787..7570f5d46f 100644
--- a/doc/src/sgml/ref/create_table_as.sgml
+++ b/doc/src/sgml/ref/create_table_as.sgml
@@ -125,8 +125,7 @@ <title>Parameters</title>
     <listitem>
      <para>
       This clause specifies optional storage parameters for the new table;
-      see <xref linkend="sql-createtable-storage-parameters"
-      endterm="sql-createtable-storage-parameters-title"/> for more
+      see <xref linkend="sql-createtable-storage-parameters"/> for more
       information.  The <literal>WITH</literal> clause
       can also include <literal>OIDS=TRUE</literal> (or just <literal>OIDS</literal>)
       to specify that rows of the new table
diff --git a/doc/src/sgml/ref/create_view.sgml b/doc/src/sgml/ref/create_view.sgml
index b325c1be50..c9726c9910 100644
--- a/doc/src/sgml/ref/create_view.sgml
+++ b/doc/src/sgml/ref/create_view.sgml
@@ -279,7 +279,7 @@ <title>Notes</title>
    </para>
 
   <refsect2 id="sql-createview-updatable-views">
-   <title id="sql-createview-updatable-views-title">Updatable Views</title>
+   <title>Updatable Views</title>
 
    <indexterm zone="sql-createview-updatable-views">
     <primary>updatable views</primary>
diff --git a/doc/src/sgml/ref/declare.sgml b/doc/src/sgml/ref/declare.sgml
index 648c2950f4..93737b67fe 100644
--- a/doc/src/sgml/ref/declare.sgml
+++ b/doc/src/sgml/ref/declare.sgml
@@ -99,8 +99,7 @@ <title>Parameters</title>
       <literal>NO SCROLL</literal> specifies that the cursor cannot be
       used to retrieve rows in a nonsequential fashion.  The default is to
       allow scrolling in some cases; this is not the same as specifying
-      <literal>SCROLL</literal>. See <xref linkend="sql-declare-notes"
-      endterm="sql-declare-notes-title"/> for details.
+      <literal>SCROLL</literal>. See <xref linkend="sql-declare-notes"/> for details.
      </para>
     </listitem>
    </varlistentry>
@@ -140,7 +139,7 @@ <title>Parameters</title>
  </refsect1>
 
  <refsect1 id="sql-declare-notes">
-  <title id="sql-declare-notes-title">Notes</title>
+  <title>Notes</title>
 
   <para>
    Normal cursors return data in text format, the same as a
diff --git a/doc/src/sgml/ref/delete.sgml b/doc/src/sgml/ref/delete.sgml
index df8cea48cf..13656e7c83 100644
--- a/doc/src/sgml/ref/delete.sgml
+++ b/doc/src/sgml/ref/delete.sgml
@@ -122,8 +122,8 @@ <title>Parameters</title>
      <para>
       A list of table expressions, allowing columns from other tables
       to appear in the <literal>WHERE</literal> condition.  This is similar
-      to the list of tables that can be specified in the <xref
-      linkend="sql-from" endterm="sql-from-title"/> of a
+      to the list of tables that can be specified in the <link
+      linkend="sql-from"><literal>FROM</literal> clause</link> of a
       <command>SELECT</command> statement; for example, an alias for
       the table name can be specified.  Do not repeat the target table
       in the <replaceable class="parameter">using_list</replaceable>,
diff --git a/doc/src/sgml/ref/do.sgml b/doc/src/sgml/ref/do.sgml
index 061218b135..c1df83156e 100644
--- a/doc/src/sgml/ref/do.sgml
+++ b/doc/src/sgml/ref/do.sgml
@@ -94,7 +94,7 @@ <title>Notes</title>
  </refsect1>
 
  <refsect1 id="sql-do-examples">
-  <title id="sql-do-examples-title">Examples</title>
+  <title>Examples</title>
   <para>
    Grant all privileges on all views in schema <literal>public</literal> to
    role <literal>webuser</literal>:
diff --git a/doc/src/sgml/ref/execute.sgml b/doc/src/sgml/ref/execute.sgml
index aab1f4b7e0..9967052d3e 100644
--- a/doc/src/sgml/ref/execute.sgml
+++ b/doc/src/sgml/ref/execute.sgml
@@ -94,9 +94,7 @@ <title>Outputs</title>
  <refsect1>
   <title>Examples</title>
   <para>
-    Examples are given in the <xref linkend="sql-prepare-examples"
-    endterm="sql-prepare-examples-title"/> section of the <xref
-    linkend="sql-prepare"/> documentation.
+    Examples are given in the <xref linkend="sql-prepare"/> documentation.
    </para>
  </refsect1>
 
diff --git a/doc/src/sgml/ref/insert.sgml b/doc/src/sgml/ref/insert.sgml
index 134092fa9c..9a623a97db 100644
--- a/doc/src/sgml/ref/insert.sgml
+++ b/doc/src/sgml/ref/insert.sgml
@@ -77,8 +77,7 @@ <title>Description</title>
   <para>
    <literal>ON CONFLICT</literal> can be used to specify an alternative
    action to raising a unique constraint or exclusion constraint
-   violation error. (See <xref linkend="sql-on-conflict"
-   endterm="sql-on-conflict-title"/> below.)
+   violation error. (See <xref linkend="sql-on-conflict"/> below.)
   </para>
 
   <para>
@@ -129,7 +128,7 @@ <title>Description</title>
   <title>Parameters</title>
 
   <refsect2 id="sql-inserting-params">
-   <title id="sql-inserting-params-title">Inserting</title>
+   <title>Inserting</title>
 
    <para>
     This section covers parameters that may be used when only
@@ -303,7 +302,7 @@ <title id="sql-inserting-params-title">Inserting</title>
   </refsect2>
 
   <refsect2 id="sql-on-conflict">
-   <title id="sql-on-conflict-title"><literal>ON CONFLICT</literal> Clause</title>
+   <title><literal>ON CONFLICT</literal> Clause</title>
    <indexterm zone="sql-insert">
     <primary>UPSERT</primary>
    </indexterm>
diff --git a/doc/src/sgml/ref/lock.sgml b/doc/src/sgml/ref/lock.sgml
index b2c7203919..cd95152f49 100644
--- a/doc/src/sgml/ref/lock.sgml
+++ b/doc/src/sgml/ref/lock.sgml
@@ -190,8 +190,7 @@ <title>Notes</title>
    <command>LOCK TABLE</command> is concerned, differing only in the rules
    about which modes conflict with which. For information on how to
    acquire an actual row-level lock, see <xref linkend="locking-rows"/>
-   and the <xref linkend="sql-for-update-share"
-   endterm="sql-for-update-share-title"/> in the <command>SELECT</command>
+   and <xref linkend="sql-for-update-share"/> in the <command>SELECT</command>
    reference documentation.
   </para>
  </refsect1>
diff --git a/doc/src/sgml/ref/pg_dump.sgml b/doc/src/sgml/ref/pg_dump.sgml
index 08cad68199..38d0c4383f 100644
--- a/doc/src/sgml/ref/pg_dump.sgml
+++ b/doc/src/sgml/ref/pg_dump.sgml
@@ -375,11 +375,11 @@ <title>Options</title>
         <replaceable class="parameter">schema</replaceable> parameter is
         interpreted as a pattern according to the same rules used by
         <application>psql</application>'s <literal>\d</literal> commands (see <xref
-        linkend="app-psql-patterns" endterm="app-psql-patterns-title"/>),
+        linkend="app-psql-patterns"/>),
         so multiple schemas can also be selected by writing wildcard characters
         in the pattern.  When using wildcards, be careful to quote the pattern
         if needed to prevent the shell from expanding the wildcards;  see
-        <xref linkend="pg-dump-examples" endterm="pg-dump-examples-title"/>.
+        <xref linkend="pg-dump-examples"/>.
        </para>
 
        <note>
@@ -526,11 +526,11 @@ <title>Options</title>
         <replaceable class="parameter">table</replaceable> parameter is
         interpreted as a pattern according to the same rules used by
         <application>psql</application>'s <literal>\d</literal> commands (see <xref
-        linkend="app-psql-patterns" endterm="app-psql-patterns-title"/>),
+        linkend="app-psql-patterns"/>),
         so multiple tables can also be selected by writing wildcard characters
         in the pattern.  When using wildcards, be careful to quote the pattern
         if needed to prevent the shell from expanding the wildcards;  see
-        <xref linkend="pg-dump-examples" endterm="pg-dump-examples-title"/>.
+        <xref linkend="pg-dump-examples"/>.
        </para>
 
        <para>
@@ -1273,7 +1273,7 @@ <title>Notes</title>
  </refsect1>
 
  <refsect1 id="pg-dump-examples">
-  <title id="pg-dump-examples-title">Examples</title>
+  <title>Examples</title>
 
   <para>
    To dump a database called <literal>mydb</literal> into a SQL-script file:
@@ -1374,7 +1374,7 @@ <title id="pg-dump-examples-title">Examples</title>
    To specify an upper-case or mixed-case name in <option>-t</option> and related
    switches, you need to double-quote the name; else it will be folded to
    lower case (see <xref
-   linkend="app-psql-patterns" endterm="app-psql-patterns-title"/>).  But
+   linkend="app-psql-patterns"/>).  But
    double quotes are special to the shell, so in turn they must be quoted.
    Thus, to dump a single table with a mixed-case name, you need something
    like
diff --git a/doc/src/sgml/ref/postgres-ref.sgml b/doc/src/sgml/ref/postgres-ref.sgml
index 53dc05a78f..43cdf792a7 100644
--- a/doc/src/sgml/ref/postgres-ref.sgml
+++ b/doc/src/sgml/ref/postgres-ref.sgml
@@ -530,8 +530,7 @@ <title>Options for Single-User Mode</title>
 
     <para>
      The following options only apply to the single-user mode
-     (see <xref linkend="app-postgres-single-user"
-     endterm="app-postgres-single-user-title"/>).
+     (see <xref linkend="app-postgres-single-user"/>).
     </para>
 
     <variablelist>
@@ -754,7 +753,7 @@ <title>Bugs</title>
  </refsect1>
 
  <refsect1 id="app-postgres-single-user">
-  <title id="app-postgres-single-user-title">Single-User Mode</title>
+  <title>Single-User Mode</title>
 
    <para>
     To start a single-user mode server, use a command like
diff --git a/doc/src/sgml/ref/prepare.sgml b/doc/src/sgml/ref/prepare.sgml
index 704fb5e4ab..34d6c9ea70 100644
--- a/doc/src/sgml/ref/prepare.sgml
+++ b/doc/src/sgml/ref/prepare.sgml
@@ -200,7 +200,7 @@ <title>Notes</title>
  </refsect1>
 
  <refsect1 id="sql-prepare-examples">
-  <title id="sql-prepare-examples-title">Examples</title>
+  <title>Examples</title>
   <para>
    Create a prepared statement for an <command>INSERT</command>
    statement, and then execute it:
diff --git a/doc/src/sgml/ref/prepare_transaction.sgml b/doc/src/sgml/ref/prepare_transaction.sgml
index d958f7a06f..3fd0d04ed2 100644
--- a/doc/src/sgml/ref/prepare_transaction.sgml
+++ b/doc/src/sgml/ref/prepare_transaction.sgml
@@ -147,7 +147,7 @@ <title>Notes</title>
  </refsect1>
 
  <refsect1 id="sql-prepare-transaction-examples">
-  <title id="sql-prepare-transaction-examples-title">Examples</title>
+  <title>Examples</title>
   <para>
    Prepare the current transaction for two-phase commit, using
    <literal>foobar</literal> as the transaction identifier:
diff --git a/doc/src/sgml/ref/psql-ref.sgml b/doc/src/sgml/ref/psql-ref.sgml
index fce7e3a585..da49d2312f 100644
--- a/doc/src/sgml/ref/psql-ref.sgml
+++ b/doc/src/sgml/ref/psql-ref.sgml
@@ -779,7 +779,7 @@ <title>Meta-Commands</title>
     If an unquoted colon (<literal>:</literal>) followed by a
     <application>psql</application> variable name appears within an argument, it is
     replaced by the variable's value, as described in <xref
-    linkend="app-psql-interpolation" endterm="app-psql-interpolation-title"/>.
+    linkend="app-psql-interpolation"/>.
     The forms <literal>:'<replaceable>variable_name</replaceable>'</literal> and
     <literal>:"<replaceable>variable_name</replaceable>"</literal> described there
     work as well.
@@ -1116,7 +1116,7 @@ <title>Meta-Commands</title>
         also shown.  For foreign tables, the associated foreign
         server is shown as well.
         (<quote>Matching the pattern</quote> is defined in
-        <xref linkend="app-psql-patterns" endterm="app-psql-patterns-title"/>
+        <xref linkend="app-psql-patterns"/>
         below.)
         </para>
 
@@ -1769,8 +1769,7 @@ <title>Meta-Commands</title>
 
         <tip>
         <para>
-        See under <xref linkend="app-psql-environment"
-        endterm="app-psql-environment-title"/> for how to configure and
+        See <xref linkend="app-psql-environment"/> for how to configure and
         customize your editor.
         </para>
         </tip>
@@ -1843,8 +1842,7 @@ <title>Meta-Commands</title>
 
         <tip>
         <para>
-        See under <xref linkend="app-psql-environment"
-        endterm="app-psql-environment-title"/> for how to configure and
+        See <xref linkend="app-psql-environment"/> for how to configure and
         customize your editor.
         </para>
         </tip>
@@ -2027,7 +2025,7 @@ <title>Meta-Commands</title>
         <para>
          Sends the current query buffer to the server and stores the
          query's output into <application>psql</application> variables (see <xref
-         linkend="app-psql-variables" endterm="app-psql-variables-title"/>).
+         linkend="app-psql-variables"/>).
          The query to be executed must return exactly one row.  Each column of
          the row is stored into a separate variable, named the same as the
          column.  For example:
@@ -2831,8 +2829,7 @@ <title>Meta-Commands</title>
 
         <para>
         Illustrations of how these different formats look can be seen in
-        the <xref linkend="app-psql-examples"
-        endterm="app-psql-examples-title"/> section.
+        <xref linkend="app-psql-examples"/>.
         </para>
 
         <tip>
@@ -2916,9 +2913,8 @@ <title>Meta-Commands</title>
 
         <para>
         Valid variable names can contain letters, digits, and
-        underscores. See the section <xref
-        linkend="app-psql-variables"
-        endterm="app-psql-variables-title"/> below for details.
+        underscores. See <xref
+        linkend="app-psql-variables"/> below for details.
         Variable names are case-sensitive.
         </para>
 
@@ -2926,8 +2922,7 @@ <title>Meta-Commands</title>
         Certain variables are special, in that they
         control <application>psql</application>'s behavior or are
         automatically set to reflect connection state.  These variables are
-        documented in <xref linkend="app-psql-variables"
-        endterm="app-psql-variables-title"/>, below.
+        documented in <xref linkend="app-psql-variables"/>, below.
         </para>
 
         <note>
@@ -3070,8 +3065,7 @@ <title>Meta-Commands</title>
         Most variables that control <application>psql</application>'s behavior
         cannot be unset; instead, an <literal>\unset</literal> command is interpreted
         as setting them to their default values.
-        See <xref linkend="app-psql-variables"
-        endterm="app-psql-variables-title"/>, below.
+        See <xref linkend="app-psql-variables"/>, below.
         </para>
         </listitem>
       </varlistentry>
@@ -3230,7 +3224,7 @@ <title>Meta-Commands</title>
   </para>
 
   <refsect3 id="app-psql-patterns">
-   <title id="app-psql-patterns-title">Patterns</title>
+   <title>Patterns</title>
 
    <indexterm>
     <primary>patterns</primary>
@@ -3323,7 +3317,7 @@ <title id="app-psql-patterns-title">Patterns</title>
   <title>Advanced Features</title>
 
    <refsect3 id="app-psql-variables">
-    <title id="app-psql-variables-title">Variables</title>
+    <title>Variables</title>
 
     <para>
     <application>psql</application> provides variable substitution
@@ -3347,8 +3341,7 @@ <title id="app-psql-variables-title">Variables</title>
 bar
 </programlisting>
     This works in both regular SQL commands and meta-commands; there is
-    more detail in <xref linkend="app-psql-interpolation"
-    endterm="app-psql-interpolation-title"/>, below.
+    more detail in <xref linkend="app-psql-interpolation"/>, below.
     </para>
 
     <para>
@@ -3742,8 +3735,7 @@ <title id="app-psql-variables-title">Variables</title>
         <para>
         These specify what the prompts <application>psql</application>
         issues should look like. See <xref
-        linkend="app-psql-prompting"
-        endterm="app-psql-prompting-title"/> below.
+        linkend="app-psql-prompting"/> below.
         </para>
         </listitem>
       </varlistentry>
@@ -3876,7 +3868,7 @@ <title id="app-psql-variables-title">Variables</title>
    </refsect3>
 
    <refsect3 id="app-psql-interpolation">
-    <title id="app-psql-interpolation-title"><acronym>SQL</acronym> Interpolation</title>
+    <title><acronym>SQL</acronym> Interpolation</title>
 
     <para>
     A key feature of <application>psql</application>
@@ -3961,7 +3953,7 @@ <title id="app-psql-interpolation-title"><acronym>SQL</acronym> Interpolation</t
    </refsect3>
 
    <refsect3 id="app-psql-prompting">
-    <title id="app-psql-prompting-title">Prompting</title>
+    <title>Prompting</title>
 
     <para>
     The prompts <application>psql</application> issues can be customized
@@ -4117,9 +4109,8 @@ <title id="app-psql-prompting-title">Prompting</title>
         <listitem>
         <para>
         The value of the <application>psql</application> variable
-        <replaceable class="parameter">name</replaceable>. See the
-        section <xref linkend="app-psql-variables"
-        endterm="app-psql-variables-title"/> for details.
+        <replaceable class="parameter">name</replaceable>. See
+        <xref linkend="app-psql-variables"/> for details.
         </para>
         </listitem>
       </varlistentry>
@@ -4205,7 +4196,7 @@ <title>Command-Line Editing</title>
 
 
  <refsect1 id="app-psql-environment">
-  <title id="app-psql-environment-title">Environment</title>
+  <title>Environment</title>
 
   <variablelist>
 
@@ -4500,7 +4491,7 @@ <title>Notes for Windows Users</title>
 
 
  <refsect1 id="app-psql-examples">
-  <title id="app-psql-examples-title">Examples</title>
+  <title>Examples</title>
 
   <para>
   The first example shows how to spread a command over several lines of
diff --git a/doc/src/sgml/ref/rollback_prepared.sgml b/doc/src/sgml/ref/rollback_prepared.sgml
index 08821a6652..175a3e9386 100644
--- a/doc/src/sgml/ref/rollback_prepared.sgml
+++ b/doc/src/sgml/ref/rollback_prepared.sgml
@@ -72,7 +72,7 @@ <title>Notes</title>
  </refsect1>
 
  <refsect1 id="sql-rollback-prepared-examples">
-  <title id="sql-rollback-prepared-examples-title">Examples</title>
+  <title>Examples</title>
   <para>
    Roll back the transaction identified by the transaction
    identifier <literal>foobar</literal>:
diff --git a/doc/src/sgml/ref/select.sgml b/doc/src/sgml/ref/select.sgml
index 8a3e86b6db..f08e3f0c82 100644
--- a/doc/src/sgml/ref/select.sgml
+++ b/doc/src/sgml/ref/select.sgml
@@ -94,7 +94,7 @@ <title>Description</title>
       in the <literal>FROM</literal> list.  A <literal>WITH</literal> query
       that is referenced more than once in <literal>FROM</literal> is
       computed only once.
-      (See <xref linkend="sql-with" endterm="sql-with-title"/> below.)
+      (See <xref linkend="sql-with"/> below.)
      </para>
     </listitem>
 
@@ -104,7 +104,7 @@ <title>Description</title>
       (Each element in the <literal>FROM</literal> list is a real or
       virtual table.)  If more than one element is specified in the
       <literal>FROM</literal> list, they are cross-joined together.
-      (See <xref linkend="sql-from" endterm="sql-from-title"/> below.)
+      (See <xref linkend="sql-from"/> below.)
      </para>
     </listitem>
 
@@ -112,8 +112,7 @@ <title>Description</title>
      <para>
       If the <literal>WHERE</literal> clause is specified, all rows
       that do not satisfy the condition are eliminated from the
-      output.  (See <xref linkend="sql-where"
-      endterm="sql-where-title"/> below.)
+      output.  (See <xref linkend="sql-where"/> below.)
      </para>
     </listitem>
 
@@ -125,8 +124,8 @@ <title>Description</title>
       values, and the results of aggregate functions are computed.
       If the <literal>HAVING</literal> clause is present, it
       eliminates groups that do not satisfy the given condition.  (See
-      <xref linkend="sql-groupby" endterm="sql-groupby-title"/> and
-      <xref linkend="sql-having" endterm="sql-having-title"/> below.)
+      <xref linkend="sql-groupby"/> and
+      <xref linkend="sql-having"/> below.)
      </para>
     </listitem>
 
@@ -135,7 +134,7 @@ <title>Description</title>
       The actual output rows are computed using the
       <command>SELECT</command> output expressions for each selected
       row or row group.  (See
-      <xref linkend="sql-select-list" endterm="sql-select-list-title"/>
+      <xref linkend="sql-select-list"/>
       below.)
      </para>
     </listitem>
@@ -145,8 +144,7 @@ <title>Description</title>
       result.  <literal>SELECT DISTINCT ON</literal> eliminates rows that
       match on all the specified expressions.  <literal>SELECT ALL</literal>
       (the default) will return all candidate rows, including
-      duplicates.  (See <xref linkend="sql-distinct"
-      endterm="sql-distinct-title"/> below.)
+      duplicates.  (See <xref linkend="sql-distinct"/> below.)
      </para>
     </listitem>
 
@@ -167,9 +165,9 @@ <title>Description</title>
       eliminating duplicate rows.  Notice that <literal>DISTINCT</literal> is
       the default behavior here, even though <literal>ALL</literal> is
       the default for <command>SELECT</command> itself.  (See
-      <xref linkend="sql-union" endterm="sql-union-title"/>, <xref
-      linkend="sql-intersect" endterm="sql-intersect-title"/>, and
-      <xref linkend="sql-except" endterm="sql-except-title"/> below.)
+      <xref linkend="sql-union"/>, <xref
+      linkend="sql-intersect"/>, and
+      <xref linkend="sql-except"/> below.)
      </para>
     </listitem>
 
@@ -179,7 +177,7 @@ <title>Description</title>
       returned rows are sorted in the specified order.  If
       <literal>ORDER BY</literal> is not given, the rows are returned
       in whatever order the system finds fastest to produce.  (See
-      <xref linkend="sql-orderby" endterm="sql-orderby-title"/> below.)
+      <xref linkend="sql-orderby"/> below.)
      </para>
     </listitem>
 
@@ -188,7 +186,7 @@ <title>Description</title>
       If the <literal>LIMIT</literal> (or <literal>FETCH FIRST</literal>) or <literal>OFFSET</literal>
       clause is specified, the <command>SELECT</command> statement
       only returns a subset of the result rows. (See <xref
-      linkend="sql-limit" endterm="sql-limit-title"/> below.)
+      linkend="sql-limit"/> below.)
      </para>
     </listitem>
 
@@ -198,8 +196,7 @@ <title>Description</title>
       or <literal>FOR KEY SHARE</literal>
       is specified, the
       <command>SELECT</command> statement locks the selected rows
-      against concurrent updates.  (See <xref linkend="sql-for-update-share"
-      endterm="sql-for-update-share-title"/> below.)
+      against concurrent updates.  (See <xref linkend="sql-for-update-share"/> below.)
      </para>
     </listitem>
    </orderedlist>
@@ -219,7 +216,7 @@ <title>Description</title>
   <title>Parameters</title>
 
   <refsect2 id="sql-with">
-   <title id="sql-with-title"><literal>WITH</literal> Clause</title>
+   <title><literal>WITH</literal> Clause</title>
 
    <para>
     The <literal>WITH</literal> clause allows you to specify one or more
@@ -296,7 +293,7 @@ <title id="sql-with-title"><literal>WITH</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-from">
-   <title id="sql-from-title"><literal>FROM</literal> Clause</title>
+   <title><literal>FROM</literal> Clause</title>
 
    <para>
     The <literal>FROM</literal> clause specifies one or more source
@@ -667,7 +664,7 @@ <title id="sql-from-title"><literal>FROM</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-where">
-   <title id="sql-where-title"><literal>WHERE</literal> Clause</title>
+   <title><literal>WHERE</literal> Clause</title>
 
    <para>
     The optional <literal>WHERE</literal> clause has the general form
@@ -684,7 +681,7 @@ <title id="sql-where-title"><literal>WHERE</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-groupby">
-   <title id="sql-groupby-title"><literal>GROUP BY</literal> Clause</title>
+   <title><literal>GROUP BY</literal> Clause</title>
 
    <para>
     The optional <literal>GROUP BY</literal> clause has the general form
@@ -758,7 +755,7 @@ <title id="sql-groupby-title"><literal>GROUP BY</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-having">
-   <title id="sql-having-title"><literal>HAVING</literal> Clause</title>
+   <title><literal>HAVING</literal> Clause</title>
 
    <para>
     The optional <literal>HAVING</literal> clause has the general form
@@ -801,7 +798,7 @@ <title id="sql-having-title"><literal>HAVING</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-window">
-   <title id="sql-window-title"><literal>WINDOW</literal> Clause</title>
+   <title><literal>WINDOW</literal> Clause</title>
 
    <para>
     The optional <literal>WINDOW</literal> clause has the general form
@@ -834,7 +831,7 @@ <title id="sql-window-title"><literal>WINDOW</literal> Clause</title>
    <para>
     The elements of the <literal>PARTITION BY</literal> list are interpreted in
     much the same fashion as elements of a
-    <xref linkend="sql-groupby" endterm="sql-groupby-title"/>, except that
+    <link linkend="sql-groupby"><literal>GROUP BY</literal> clause</link>, except that
     they are always simple expressions and never the name or number of an
     output column.
     Another difference is that these expressions can contain aggregate
@@ -846,7 +843,7 @@ <title id="sql-window-title"><literal>WINDOW</literal> Clause</title>
    <para>
     Similarly, the elements of the <literal>ORDER BY</literal> list are interpreted
     in much the same fashion as elements of an
-    <xref linkend="sql-orderby" endterm="sql-orderby-title"/>, except that
+    <link linkend="sql-orderby"><literal>ORDER BY</literal> clause</link>, except that
     the expressions are always taken as simple expressions and never the name
     or number of an output column.
    </para>
@@ -920,8 +917,8 @@ <title id="sql-window-title"><literal>WINDOW</literal> Clause</title>
    <para>
     The purpose of a <literal>WINDOW</literal> clause is to specify the
     behavior of <firstterm>window functions</firstterm> appearing in the query's
-    <xref linkend="sql-select-list" endterm="sql-select-list-title"/> or
-    <xref linkend="sql-orderby" endterm="sql-orderby-title"/>.  These functions
+    <link linkend="sql-select-list"><literal>SELECT</literal> list</link> or
+    <link linkend="sql-orderby"><literal>ORDER BY</literal> clause</link>.  These functions
     can reference the <literal>WINDOW</literal> clause entries by name
     in their <literal>OVER</literal> clauses.  A <literal>WINDOW</literal> clause
     entry does not have to be referenced anywhere, however; if it is not
@@ -948,7 +945,7 @@ <title id="sql-window-title"><literal>WINDOW</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-select-list">
-   <title id="sql-select-list-title"><command>SELECT</command> List</title>
+   <title><command>SELECT</command> List</title>
 
    <para>
     The <command>SELECT</command> list (between the key words
@@ -1029,7 +1026,7 @@ <title id="sql-select-list-title"><command>SELECT</command> List</title>
   </refsect2>
 
   <refsect2 id="sql-distinct">
-   <title id="sql-distinct-title"><literal>DISTINCT</literal> Clause</title>
+   <title><literal>DISTINCT</literal> Clause</title>
 
    <para>
     If <literal>SELECT DISTINCT</literal> is specified, all duplicate rows are
@@ -1074,7 +1071,7 @@ <title id="sql-distinct-title"><literal>DISTINCT</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-union">
-   <title id="sql-union-title"><literal>UNION</literal> Clause</title>
+   <title><literal>UNION</literal> Clause</title>
 
    <para>
     The <literal>UNION</literal> clause has this general form:
@@ -1127,7 +1124,7 @@ <title id="sql-union-title"><literal>UNION</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-intersect">
-   <title id="sql-intersect-title"><literal>INTERSECT</literal> Clause</title>
+   <title><literal>INTERSECT</literal> Clause</title>
 
    <para>
     The <literal>INTERSECT</literal> clause has this general form:
@@ -1175,7 +1172,7 @@ <title id="sql-intersect-title"><literal>INTERSECT</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-except">
-   <title id="sql-except-title"><literal>EXCEPT</literal> Clause</title>
+   <title><literal>EXCEPT</literal> Clause</title>
 
    <para>
     The <literal>EXCEPT</literal> clause has this general form:
@@ -1219,7 +1216,7 @@ <title id="sql-except-title"><literal>EXCEPT</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-orderby">
-   <title id="sql-orderby-title"><literal>ORDER BY</literal> Clause</title>
+   <title><literal>ORDER BY</literal> Clause</title>
 
    <para>
     The optional <literal>ORDER BY</literal> clause has this general form:
@@ -1317,7 +1314,7 @@ <title id="sql-orderby-title"><literal>ORDER BY</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-limit">
-   <title id="sql-limit-title"><literal>LIMIT</literal> Clause</title>
+   <title><literal>LIMIT</literal> Clause</title>
 
    <para>
     The <literal>LIMIT</literal> clause consists of two independent
@@ -1397,7 +1394,7 @@ <title id="sql-limit-title"><literal>LIMIT</literal> Clause</title>
   </refsect2>
 
   <refsect2 id="sql-for-update-share">
-   <title id="sql-for-update-share-title">The Locking Clause</title>
+   <title>The Locking Clause</title>
 
    <para>
     <literal>FOR UPDATE</literal>, <literal>FOR NO KEY UPDATE</literal>, <literal>FOR SHARE</literal>
@@ -2001,7 +1998,7 @@ <title><literal>LIMIT</literal> and <literal>OFFSET</literal></title>
     used by <productname>MySQL</productname>.  The SQL:2008 standard
     has introduced the clauses <literal>OFFSET ... FETCH {FIRST|NEXT}
     ...</literal> for the same functionality, as shown above
-    in <xref linkend="sql-limit" endterm="sql-limit-title"/>.  This
+    in <xref linkend="sql-limit"/>.  This
     syntax is also used by <productname>IBM DB2</productname>.
     (Applications written for <productname>Oracle</productname>
     frequently use a workaround involving the automatically
diff --git a/doc/src/sgml/ref/update.sgml b/doc/src/sgml/ref/update.sgml
index c0d0f7134d..5740fb96e9 100644
--- a/doc/src/sgml/ref/update.sgml
+++ b/doc/src/sgml/ref/update.sgml
@@ -170,8 +170,8 @@ <title>Parameters</title>
       A list of table expressions, allowing columns from other tables
       to appear in the <literal>WHERE</literal> condition and the update
       expressions. This is similar to the list of tables that can be
-      specified in the <xref linkend="sql-from"
-      endterm="sql-from-title"/> of a <command>SELECT</command>
+      specified in the <link linkend="sql-from"><literal>FROM</literal>
+      clause</link> of a <command>SELECT</command>
       statement.  Note that the target table must not appear in the
       <replaceable>from_list</replaceable>, unless you intend a self-join (in which
       case it must appear with an alias in the <replaceable>from_list</replaceable>).
diff --git a/doc/src/sgml/ref/values.sgml b/doc/src/sgml/ref/values.sgml
index 849220b120..5c7aeb2a49 100644
--- a/doc/src/sgml/ref/values.sgml
+++ b/doc/src/sgml/ref/values.sgml
@@ -85,7 +85,7 @@ <title>Parameters</title>
       rows.  This expression can refer to the columns of the
       <command>VALUES</command> result as <literal>column1</literal>, <literal>column2</literal>,
       etc.  For more details see
-      <xref linkend="sql-orderby" endterm="sql-orderby-title"/>.
+      <xref linkend="sql-orderby"/>.
      </para>
     </listitem>
    </varlistentry>
@@ -95,7 +95,7 @@ <title>Parameters</title>
     <listitem>
      <para>
       A sorting operator.  For details see
-      <xref linkend="sql-orderby" endterm="sql-orderby-title"/>.
+      <xref linkend="sql-orderby"/>.
      </para>
     </listitem>
    </varlistentry>
@@ -105,7 +105,7 @@ <title>Parameters</title>
     <listitem>
      <para>
       The maximum number of rows to return.  For details see
-      <xref linkend="sql-limit" endterm="sql-limit-title"/>.
+      <xref linkend="sql-limit"/>.
      </para>
     </listitem>
    </varlistentry>
@@ -116,7 +116,7 @@ <title>Parameters</title>
      <para>
       The number of rows to skip before starting to return rows.
       For details see
-      <xref linkend="sql-limit" endterm="sql-limit-title"/>.
+      <xref linkend="sql-limit"/>.
      </para>
     </listitem>
    </varlistentry>
-- 
2.15.1

